@@ -1,7 +1,7 @@
 package Data::Section::Seekable;
 
 our $DATE = '2015-06-12'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 1;
 # ABSTRACT: Read and write parts from data section
@@ -18,7 +18,7 @@ Data::Section::Seekable - Read and write parts from data section
 
 =head1 VERSION
 
-This document describes version 0.02 of Data::Section::Seekable (from Perl distribution Data-Section-Seekable), released on 2015-06-12.
+This document describes version 0.03 of Data::Section::Seekable (from Perl distribution Data-Section-Seekable), released on 2015-06-12.
 
 =head1 DESCRIPTION
 
@@ -39,13 +39,14 @@ First line of data section is the header line and must be:
  Data::Section::Seekable v1
 
 After the header line, comes one or more TOC ("table of content") lines. Each
-TOC line must match:
+TOC line must match this Perl regex:
 
- ([^,]+),(\d+),(\d+)
+ /^([^,]+), (\d+), (\d+) (?:, (.*))?/x
 
 The first field is the name, the second field is the offset, the third field is
 the length. Offset starts from 0 and the zero is counted from after the blank
-line after the last TOC line.
+line after the last TOC line. The fourth field is to store extra information, it
+is optional and can contain zero or more non-newline characters.
 
 After the last TOC line is a blank line. And after that is content.
 
