@@ -1,7 +1,7 @@
 package Data::Section::Seekable::Reader;
 
 our $DATE = '2015-06-12'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -27,7 +27,7 @@ sub new {
             or die "Unexpected end of data section while reading header line";
         chomp($header_line);
         $header_line eq 'Data::Section::Seekable v1'
-            or die "Invalid header, must be 'Data::Section::Seekable v1'";
+            or die "Invalid header, must be 'Data::Section::Seekable v1' (got: $header_line)";
 
         my %toc;
         my $i = 0;
@@ -36,10 +36,11 @@ sub new {
             my $toc_line = <$fh>;
             defined($toc_line)
                 or die "Unexpected end of data section while reading TOC line #$i";
+            chomp($toc_line);
             $toc_line =~ /\S/ or last;
-            $toc_line =~ /^([^,]+),(\d+),(\d+)$/
-                or die "Invalid TOC line #$i in data section";
-            $toc{$1} = [$2, $3];
+            $toc_line =~ /^([^,]+),(\d+),(\d+)(?:,(.*))?$/
+                or die "Invalid TOC line #$i in data section: $toc_line";
+            $toc{$1} = [$2, $3, $4];
         }
         my $pos = tell $fh;
         $toc{$_}[0] += $pos for keys %toc;
@@ -69,6 +70,15 @@ sub read_part {
     $content;
 }
 
+sub read_extra {
+    my ($self, $name) = @_;
+
+    defined($self->{_toc}{$name})
+        or die "Unknown part '$name'";
+
+    $self->{_toc}{$name}[2];
+}
+
 1;
 # ABSTRACT: Read parts from data section
 
@@ -84,7 +94,7 @@ Data::Section::Seekable::Reader - Read parts from data section
 
 =head1 VERSION
 
-This document describes version 0.02 of Data::Section::Seekable::Reader (from Perl distribution Data-Section-Seekable), released on 2015-06-12.
+This document describes version 0.03 of Data::Section::Seekable::Reader (from Perl distribution Data-Section-Seekable), released on 2015-06-12.
 
 =head1 SYNOPSIS
 
@@ -96,11 +106,14 @@ In your script:
 
  my $p2 = $reader->read_part('part2'); # -> "This is part\ntwo\n"
  my $p1 = $reader->read_part('part1'); # -> "This is part1\n"
+ my $p3 = $reader->read_part('part3'); # dies
+ my $e1 = $reader->read_extra('part1'); # -> undef
+ my $e1 = $reader->read_extra('part2'); # -> "important"
 
  __DATA__
  Data::Section::Seekable v1
  part1,0,14
- part2,14,17
+ part2,14,17,important
 
  This is part1
  This is part
@@ -138,6 +151,11 @@ Return list of all known parts in the data section, sorted lexicographically.
 
 Read a part named C<$name>. Will die if part is unknown.
 
+=head2 $reader->read_extra($name) => str
+
+Read extra information (the fourth field of TOC line) for part named C<$name>.
+Will die if part is unknown.
+
 =head1 SEE ALSO
 
 L<Data::Section::Seekable> for the description of the data format.
