@@ -1,7 +1,7 @@
 package Data::Section::Seekable::Writer;
 
 our $DATE = '2015-06-12'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -21,10 +21,11 @@ sub new {
 }
 
 sub add_part {
-    my ($self, $name, $part_content) = @_;
+    my ($self, $name, $part_content, $extra) = @_;
     die "Name cannot be empty" unless length($name);
     die "Name cannot contain comma" if $name =~ /,/;
-    $self->{_parts}{$name} = $part_content;
+    die "Extra cannot contain newline" if defined($extra) && $extra =~ /\R/;
+    $self->{_parts}{$name} = [$part_content, $extra];
 }
 
 sub as_string {
@@ -39,9 +40,11 @@ sub as_string {
             $content .= $self->{separator};
             $offset += length($self->{separator});
         }
-        push @toc, "$name,$offset," . length($self->{_parts}{$name}) . "\n";
-        $content .= $self->{_parts}{$name};
-        $offset += length($self->{_parts}{$name});
+        my ($part_content, $extra) = @{ $self->{_parts}{$name} };
+        push @toc, "$name,$offset," . length($part_content) .
+            (defined($extra) ? ",$extra" : "") . "\n";
+        $content .= $part_content;
+        $offset += length($part_content);
     }
 
     join(
@@ -68,7 +71,7 @@ Data::Section::Seekable::Writer - Generate data section with multiple parts
 
 =head1 VERSION
 
-This document describes version 0.02 of Data::Section::Seekable::Writer (from Perl distribution Data-Section-Seekable), released on 2015-06-12.
+This document describes version 0.03 of Data::Section::Seekable::Writer (from Perl distribution Data-Section-Seekable), released on 2015-06-12.
 
 =head1 SYNOPSIS
 
